CVXOPTKLU
======

KLU Add-On for CVXOPT, Python Software for Convex Optimization 

This repository is a fork of the CVXOPT with KLU fork by Uriel Sandoval (@sanurielf). All credit goes to the original authors. 

* [CVXOPT Website](http://cvxopt.org)
* [CVXOPT with KLU](https://github.com/sanurielf/cvxopt)
